@@ -84,7 +84,7 @@
 #define KAUTHCORE_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KAUTHCORE_NO_DEPRECATED
-#  define KAUTHCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56b00
+#  define KAUTHCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56c00
 #endif
 #ifdef KAUTHCORE_NO_DEPRECATED_WARNINGS
 #  define KAUTHCORE_DEPRECATED_WARNINGS_SINCE 0
@@ -94,7 +94,7 @@
 #  ifdef KAUTHCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KAUTHCORE_DEPRECATED_WARNINGS_SINCE KAUTHCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KAUTHCORE_DEPRECATED_WARNINGS_SINCE 0x56b00
+#    define KAUTHCORE_DEPRECATED_WARNINGS_SINCE 0x56c00
 #  endif
 #endif
 
